from typing import Dict

from .style import Style


DEFAULT_STYLES: Dict[str, Style] = {
    "none": Style.null(),
    "reset": Style(
        fg="default",
        bg="default",
        dim=False,
        bold=False,
        italic=False,
        underline=False,
        blink=False,
        blink2=False,
        reverse=False,
        conceal=False,
        strike=False,
    ),
    "dim": Style(dim=True),
    "bright": Style(dim=False),
    "bold": Style(bold=True),
    "strong": Style(bold=True),
    "code": Style(reverse=True, bold=True),
    "italic": Style(italic=True),
    "emphasize": Style(italic=True),
    "underline": Style(underline=True),
    "blink": Style(blink=True),
    "blink2": Style(blink2=True),
    "reverse": Style(reverse=True),
    "strike": Style(strike=True),
    "black": Style(fg="black"),
    "red": Style(fg="red"),
    "green": Style(fg="green"),
    "yellow": Style(fg="yellow"),
    "magenta": Style(fg="magenta"),
    "cyan": Style(fg="cyan"),
    "white": Style(fg="white"),
    "inspect.attr": Style(fg="yellow", italic=True),
    "inspect.attr.dunder": Style(fg="yellow", italic=True, dim=True),
    "inspect.callable": Style(bold=True, fg="red"),
    "inspect.def": Style(italic=True, fg="vcyan"),
    "inspect.error": Style(bold=True, fg="red"),
    "inspect.equals": Style(),
    "inspect.help": Style(fg="cyan"),
    "inspect.doc": Style(dim=True),
    "inspect.value.border": Style(fg="green"),
    "live.ellipsis": Style(bold=True, fg="red"),
    "layout.tree.row": Style(dim=False, fg="red"),
    "layout.tree.column": Style(dim=False, fg="blue"),
    "logging.keyword": Style(bold=True, fg="yellow"),
    "logging.level.notset": Style(dim=True),
    "logging.level.debug": Style(fg="green"),
    "logging.level.info": Style(fg="blue"),
    "logging.level.warning": Style(fg="red"),
    "logging.level.error": Style(fg="red", bold=True),
    "logging.level.critical": Style(fg="red", bold=True, reverse=True),
    "log.level": Style.null(),
    "log.time": Style(fg="cyan", dim=True),
    "log.message": Style.null(),
    "log.path": Style(dim=True),
    "repr.ellipsis": Style(fg="yellow"),
    "repr.indent": Style(fg="green", dim=True),
    "repr.error": Style(fg="red", bold=True),
    "repr.str": Style(fg="green", italic=False, bold=False),
    "repr.brace": Style(bold=True),
    "repr.comma": Style(bold=True),
    "repr.ipv4": Style(bold=True, fg="vgreen"),
    "repr.ipv6": Style(bold=True, fg="vgreen"),
    "repr.eui48": Style(bold=True, fg="vgreen"),
    "repr.eui64": Style(bold=True, fg="vgreen"),
    "repr.tag_start": Style(bold=True),
    "repr.tag_name": Style(fg="vmagenta", bold=True),
    "repr.tag_contents": Style(fg="default"),
    "repr.tag_end": Style(bold=True),
    "repr.attrib_name": Style(fg="yellow", italic=False),
    "repr.attrib_equal": Style(bold=True),
    "repr.attrib_value": Style(fg="magenta", italic=False),
    "repr.number": Style(fg="cyan", bold=True, italic=False),
    "repr.bool_true": Style(fg="vgreen", italic=True),
    "repr.bool_false": Style(fg="vred", italic=True),
    "repr.none": Style(fg="magenta", italic=True),
    "repr.url": Style(underline=True, fg="vblue", italic=False, bold=False),
    "repr.uuid": Style(fg="vyellow", bold=False),
    "repr.call": Style(fg="magenta", bold=True),
    "repr.path": Style(fg="magenta"),
    "repr.filename": Style(fg="vmagenta"),
    "rule.line": Style(fg="vgreen"),
    "rule.text": Style.null(),
    "json.brace": Style(bold=True),
    "json.bool_true": Style(fg="vgreen", italic=True),
    "json.bool_false": Style(fg="vred", italic=True),
    "json.null": Style(fg="magenta", italic=True),
    "json.number": Style(fg="cyan", bold=True, italic=False),
    "json.str": Style(fg="green", italic=False, bold=False),
    "json.key": Style(fg="blue", bold=True),
    "prompt": Style.null(),
    "prompt.choices": Style(fg="magenta", bold=True),
    "prompt.default": Style(fg="cyan", bold=True),
    "prompt.invalid": Style(fg="red"),
    "prompt.invalid.choice": Style(fg="red"),
    "pretty": Style.null(),
    "scope.border": Style(fg="blue"),
    "scope.key": Style(fg="yellow", italic=True),
    "scope.key.special": Style(fg="yellow", italic=True, dim=True),
    "scope.equals": Style(fg="red"),
    "table.header": Style(bold=True),
    "table.footer": Style(bold=True),
    "table.cell": Style.null(),
    "table.title": Style(italic=True),
    "table.caption": Style(italic=True, dim=True),
    "traceback.error": Style(fg="red", italic=True),
    "traceback.border.syntax_error": Style(fg="vred"),
    "traceback.border": Style(fg="red"),
    "traceback.text": Style.null(),
    "traceback.title": Style(fg="red", bold=True),
    "traceback.exc_type": Style(fg="vred", bold=True),
    "traceback.exc_value": Style.null(),
    "traceback.offset": Style(fg="vred", bold=True),
    "bar.back": Style(fg="grey23"),
    "bar.complete": Style(fg="rgb(249,38,114)"),
    "bar.finished": Style(fg="rgb(114,156,31)"),
    "bar.pulse": Style(fg="rgb(249,38,114)"),
    "progress.description": Style.null(),
    "progress.filesize": Style(fg="green"),
    "progress.filesize.total": Style(fg="green"),
    "progress.download": Style(fg="green"),
    "progress.elapsed": Style(fg="yellow"),
    "progress.percentage": Style(fg="magenta"),
    "progress.remaining": Style(fg="cyan"),
    "progress.data.speed": Style(fg="red"),
    "progress.spinner": Style(fg="green"),
    "status.spinner": Style(fg="green"),
    "tree": Style(),
    "tree.line": Style(),
    "markdown.paragraph": Style(),
    "markdown.text": Style(),
    "markdown.emph": Style(italic=True),
    "markdown.strong": Style(bold=True),
    "markdown.code": Style(bg="black", fg="vwhite"),
    "markdown.code_block": Style(dim=True, fg="cyan", bg="black"),
    "markdown.block_quote": Style(fg="magenta"),
    "markdown.list": Style(fg="cyan"),
    "markdown.item": Style(),
    "markdown.item.bullet": Style(fg="yellow", bold=True),
    "markdown.item.number": Style(fg="yellow", bold=True),
    "markdown.hr": Style(fg="yellow"),
    "markdown.h1.border": Style(),
    "markdown.h1": Style(bold=True),
    "markdown.h2": Style(bold=True, underline=True),
    "markdown.h3": Style(bold=True),
    "markdown.h4": Style(bold=True, dim=True),
    "markdown.h5": Style(underline=True),
    "markdown.h6": Style(italic=True),
    "markdown.h7": Style(italic=True, dim=True),
    "markdown.link": Style(fg="vblue"),
    "markdown.link_url": Style(fg="blue"),
}
